summaryrefslogtreecommitdiffstats
path: root/src/ciwidgetmgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ciwidgetmgr.h')
-rw-r--r--src/ciwidgetmgr.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/ciwidgetmgr.h b/src/ciwidgetmgr.h
index b79fc06..f92a877 100644
--- a/src/ciwidgetmgr.h
+++ b/src/ciwidgetmgr.h
@@ -11,19 +11,19 @@
#ifndef CIWIDGETMGR_H
#define CIWIDGETMGR_H
-#include <qmap.h>
-#include <qstring.h>
+#include <tqmap.h>
+#include <tqstring.h>
class Button;
class CNItem;
class Slider;
-class QCanvas;
+class TQCanvas;
class Widget;
-typedef QMap<QString, Widget*> WidgetMap;
+typedef TQMap<TQString, Widget*> WidgetMap;
/**
-This class handles the widgets (those things associated with CNItems that use QWidgets.
+This class handles the widgets (those things associated with CNItems that use TQWidgets.
This class is pretty much to maintain a tidy interface: the functions could just as well be
all shoved in CNItem, but that gets messy.
@author David Saxton
@@ -31,41 +31,41 @@ all shoved in CNItem, but that gets messy.
class CIWidgetMgr
{
public:
- CIWidgetMgr( QCanvas *canvas, CNItem *item );
+ CIWidgetMgr( TQCanvas *canvas, CNItem *item );
virtual ~CIWidgetMgr();
/**
* Set the top-left position from which mouse events are interpreted and the
* widgets are drawn from.
*/
- void setWidgetsPos( const QPoint &pos );
+ void setWidgetsPos( const TQPoint &pos );
/**
* Returns a pointer to the widget with the given id, or NULL if no such
* widgets are found.
*/
- Widget *widgetWithID( const QString &id ) const;
- Button *button( const QString &id ) const;
- Slider *slider( const QString &id ) const;
- void setButtonState( const QString &id, int state );
+ Widget *widgetWithID( const TQString &id ) const;
+ Button *button( const TQString &id ) const;
+ Slider *slider( const TQString &id ) const;
+ void setButtonState( const TQString &id, int state );
/**
* Adds a slider with the given id and values to the position
*/
- Slider* addSlider( const QString &id, int minValue, int maxValue, int pageStep, int value, Qt::Orientation orientation, const QRect & pos );
+ Slider* addSlider( const TQString &id, int minValue, int maxValue, int pageStep, int value, Qt::Orientation orientation, const TQRect & pos );
/**
* Essentially the same as addDisplayText, but displays a button with
* text on it. The virtual functions buttonPressed( const QString &id ) and
* buttonReleased( const QString &id ) are called as appropriate with button id
*/
- Button* addButton( const QString &id, const QRect & pos, const QString &display, bool toggle = false );
+ Button* addButton( const TQString &id, const TQRect & pos, const TQString &display, bool toggle = false );
/**
* Adds a button with a QPixmap pixmap on it instead of text
* @see void addButton( const QString &id, QRect pos, const QString &display )
*/
- Button* addButton( const QString &id, const QRect & pos, QPixmap pixmap, bool toggle = false );
+ Button* addButton( const TQString &id, const TQRect & pos, TQPixmap pixmap, bool toggle = false );
/**
* Removes the widget with the given id.
*/
- void removeWidget( const QString & id );
+ void removeWidget( const TQString & id );
/**
* Sets whether or not to draw the widgets (drawing widgets mucks up SVG
* export). This function just calls either hide() or show() in each widget.
@@ -80,23 +80,23 @@ public:
void enterEvent();
void leaveEvent();
- virtual void buttonStateChanged( const QString &/*id*/, bool /*on*/ ) {};
- virtual void sliderValueChanged( const QString &/*id*/, int /*value*/ ) {};
+ virtual void buttonStateChanged( const TQString &/*id*/, bool /*on*/ ) {};
+ virtual void sliderValueChanged( const TQString &/*id*/, int /*value*/ ) {};
int mgrX() const { return m_pos.x(); }
int mgrY() const { return m_pos.y(); }
/**
* Draw the widgets using the given painter. This function isn't actually
* used to draw the widgets on the canvas, as they are QCanvasItems
* themselves, but allows other classes (e.g. ItemLibrary) to draw them
* using a special painter.
*/
- void drawWidgets( QPainter &p );
+ void drawWidgets( TQPainter &p );
protected:
WidgetMap m_widgetMap;
- QPoint m_pos;
- QCanvas *p_canvas;
+ TQPoint m_pos;
+ TQCanvas *p_canvas;
CNItem *p_cnItem;
};
@@ -31,41 +31,41 @@ all shoved in CNItem, but that gets messy.
/**
* Essentially the same as addDisplayText, but displays a button with
- * text on it. The virtual functions buttonPressed( const QString &id ) and
- * buttonReleased( const QString &id ) are called as appropriate with button id
+ * text on it. The virtual functions buttonPressed( const TQString &id ) and
+ * buttonReleased( const TQString &id ) are called as appropriate with button id
*/
@@ -31,41 +31,41 @@ all shoved in CNItem, but that gets messy.
/**
- * Adds a button with a QPixmap pixmap on it instead of text
- * @see void addButton( const QString &id, QRect pos, const QString &display )
+ * Adds a button with a TQPixmap pixmap on it instead of text
+ * @see void addButton( const TQString &id, TQRect pos, const TQString &display )
*/
@@ -80,23 +80,23 @@ public:
/**
* Draw the widgets using the given painter. This function isn't actually
- * used to draw the widgets on the canvas, as they are QCanvasItems
+ * used to draw the widgets on the canvas, as they are TQCanvasItems
* themselves, but allows other classes (e.g. ItemLibrary) to draw them
* using a special painter.